#request-community-submission-tab-container {
  .ui.attached.segment{
    border: 0;
  }
}

@secondaryColor: #fb8273;

#request-community-submission-tab {

  &.ui.menu:last-child {
    margin-bottom: 0;
  }

  &.ui.menu.secondary {
    .item.active {
      border-color: @secondaryColor;
    }
  }
}


