/*
 *   Copyright (C) 2020 CERN.
 *   Copyright (C) 2020 Northwestern University.
 *   Copyright (C) 2021 Graz University of Technology.
 *   Copyright (C) 2021 New York University.
 *
 * Invenio RDM Records is free software; you can redistribute it and/or modify
 * it under the terms of the MIT License; see LICENSE file for more details.
 */

@import "./licenses.less";

.sixteen.wide.tablet.five.wide.computer.column.sidebar {
  padding-top: 1rem;

  @media screen and (max-width: @computerBreakpoint) {
    display: inline-flex;
    flex-wrap: wrap;
    justify-content: space-between;
  }
}

.ui.segment.rdm-sidebar {

  @media screen and (max-width: @computerBreakpoint) {
    box-shadow: none;
    flex-basis: calc(50% - 0.5rem);
    margin-top: 0rem;
    margin-bottom: 1rem;

    &:first-child,
    &:last-child {
      margin-top: 0rem;
      margin-bottom: 1rem;
    }
  }

  @media screen and (max-width: @tabletBreakpoint) {
    flex-basis: 100%;
  }

  h2.ui.small.header {
    margin-bottom: 0.5rem;
    padding-bottom: 0.5rem;
    border-bottom: 1px solid rgba(0, 0, 0, 0.1);
  }
}
