/*
 *   Copyright (C) 2020 CERN.
 *   Copyright (C) 2020 Northwestern University.
 *   Copyright (C) 2021 Graz University of Technology.
 *   Copyright (C) 2021-2022 New York University.
 *
 * Invenio RDM Records is free software; you can redistribute it and/or modify
 * it under the terms of the MIT License; see LICENSE file for more details.
 */

.creatibutors {
  margin: 0rem 0rem 0.5rem 0rem;
  display: flex;
  flex-wrap: wrap;
  &:last-child {
    margin-bottom: 0rem;
  }

  dt {
    font-weight: bold;
    margin: 0rem 0.25rem 0rem 0rem;

    &.hidden {
      display: none;
    }
  }

  .creatibutor-wrap {
    color: @mutedTextColor;
    display: flex;
    flex-wrap: wrap;
    &:nth-child(n):not(:last-child) {
      margin-right: 1rem;
    }
    .identifier-link, .group.icon {
      margin: 0 .1rem 0 .2rem;
    }
  }
}
.creatibutor-link {
  color: @mutedTextColor;
  &:hover {
    text-decoration: none;
    span {
      color: @mutedTextColor;
      text-decoration: underline;
    }
    sup {
      color: @mutedTextColor;
    }
  }
  sup {
    color: @mutedTextColor;
    padding-left: .1rem;
  }
}
.affiliations-list {
  color: @mutedTextColor;
}
.row.ui.accordion.affiliations-accordion {
  padding-bottom: 1.5rem;

  &:last-child {
    padding-bottom: 3rem;
  }

  .title {
    cursor: default;
  }

  .button-wrapper {
    display: flex;
    flex-direction: column;
    width: 100%;
    height: 100%;
    justify-content: flex-end;
    align-items: flex-end;
    box-sizing: border-box;
    padding-top: 1.5rem;

    @media screen and (min-width: @tabletBreakpoint) {
      padding-top: 0rem;
    }

    .ui.button.affiliations-button {
      margin: 0px;
      min-width: max-content;
    }
  }
  .content {
    dl {
      font-size: @font-size-small;
      background-color: #f9fafb;
      padding: 1rem;
      margin: 1.2rem 0rem 0rem 0rem;
    }
  }
}
