/*
 *   Copyright (C) 2020 CERN.
 *   Copyright (C) 2020 Northwestern University.
 *   Copyright (C) 2021 Graz University of Technology.
 *   Copyright (C) 2021 New York University.
 *
 * Invenio RDM Records is free software; you can redistribute it and/or modify
 * it under the terms of the MIT License; see LICENSE file for more details.
 */

#additional-details {
  .ui.top.attached.menu {

    @media screen and (max-width: @computerBreakpoint) {
      flex-wrap: wrap;
    }

    &:not(.tabular) {
      @media screen and (max-width: @computerBreakpoint) {
        border-bottom: 0px;
      }
    }

    .item {
      flex: 1 0 auto;

      @media screen and (max-width: @computerBreakpoint) {
        border-bottom: 1px solid #D4D4D5;
        font-weight: bold;
      }
    }
  }

  .ui.tab.segment {
    padding: 1.5rem 1rem;

    h3.ui.tiny.header {
      margin-bottom: 0.5rem;
    }

    dl.details-list {
      margin-top: 0rem;

      dt.hidden {
        display: none;
      }
    }
  }

  .ui.segment[class*="bottom attached"]:last-child {
    margin-bottom: 1rem;
  }
}
